package com.pointrlabs.sample.selection;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.DiffUtil;
import androidx.recyclerview.widget.ListAdapter;
import androidx.recyclerview.widget.RecyclerView;

import com.pointrlabs.core.management.models.Building;
import com.pointrlabs.sample.R;

/**
 * List adapter for venue selection list
 */
public class BuildingSelectionAdapter extends ListAdapter<Building, BuildingSelectionAdapter.BuildingItemAdapter> {

    /**
     * Listener interface to advertise events of Venue item rows
     */
    public interface Listener {
        /**
         * Invoked when user selects a venue
         *
         * @param buildingInternalIdentifier of {@link Building} that's selected
         */
        void onBuildingSelected(int buildingInternalIdentifier);
    }

    private final Listener listener;

    BuildingSelectionAdapter(Listener listener) {
        super(new BuildingItemCallback());
        this.listener = listener;
    }

    @NonNull
    @Override
    public BuildingItemAdapter onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        final LayoutInflater inflater = LayoutInflater.from(parent.getContext());
        final View venueItemView = inflater.inflate(R.layout.item_venue, parent, false);
        return new BuildingItemAdapter(venueItemView, listener);
    }

    @Override
    public void onBindViewHolder(@NonNull BuildingItemAdapter holder, int position) {
        holder.bind(getItem(position));
    }

    static final class BuildingItemAdapter extends RecyclerView.ViewHolder {

        private final TextView venueTitleTextView;
        private Building building;

        BuildingItemAdapter(@NonNull View itemView, @NonNull Listener listener) {
            super(itemView);
            venueTitleTextView = itemView.findViewById(R.id.titleTextView);
            itemView.setOnClickListener(v -> listener.onBuildingSelected(building.getInternalIdentifier()));
        }

        void bind(@NonNull Building building) {
            this.building = building;
            venueTitleTextView.setText(building.getTitle());
        }
    }

    private static final class BuildingItemCallback extends DiffUtil.ItemCallback<Building> {

        @Override
        public boolean areItemsTheSame(@NonNull Building oldItem, @NonNull Building newItem) {
            return oldItem.hasSameInternalIdentifier(newItem);
        }

        @Override
        public boolean areContentsTheSame(@NonNull Building oldItem, @NonNull Building newItem) {
            return oldItem.equals(newItem);
        }
    }
}
