package com.pointrlabs.sample.splash;

import android.content.Context;
import android.util.AttributeSet;
import android.view.Gravity;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.FrameLayout;
import android.widget.ImageView;

import com.pointrlabs.core.R;

public class PointrProgressSpinner extends FrameLayout {
    private final ImageView outerCircle;
    private final ImageView innerCircle;
    private final Animation counterClockWiseRotation;
    private final Animation clockWiseRotation;

    public PointrProgressSpinner(Context context) {
        this(context, null);
    }

    public PointrProgressSpinner(Context context, AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public PointrProgressSpinner(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);

        outerCircle = new ImageView(context);
        outerCircle.setImageResource(R.drawable.ic_logo_outer_arc);
        LayoutParams lpOuter =
            new LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
        lpOuter.gravity = Gravity.CENTER;
        outerCircle.setLayoutParams(lpOuter);
        addView(outerCircle);

        innerCircle = new ImageView(context);
        innerCircle.setImageResource(R.drawable.ic_logo_inner_arc);
        LayoutParams lpInner =
            new LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
        lpInner.gravity = Gravity.CENTER;
        innerCircle.setLayoutParams(lpInner);
        addView(innerCircle);

        ImageView pin = new ImageView(context);
        pin.setImageResource(R.drawable.ic_logo_indicator);
        LayoutParams lpPin =
            new LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
        lpPin.gravity = Gravity.CENTER;
        pin.setLayoutParams(lpPin);
        addView(pin);

        clockWiseRotation = AnimationUtils.loadAnimation(context, R.anim.rotate_cw);
        counterClockWiseRotation = AnimationUtils.loadAnimation(context, R.anim.rotate_ccw);
    }

    public void show() {
        setVisibility(VISIBLE);
        outerCircle.startAnimation(clockWiseRotation);
        innerCircle.startAnimation(counterClockWiseRotation);
    }

    public void hide() {
        outerCircle.clearAnimation();
        innerCircle.clearAnimation();
        setVisibility(GONE);
    }
}
